==> pentobi-18.1.tar.xz: pentobi-18.1/README.md <==
Pentobi Readme
==============

![Screenshot](https://pentobi.sourceforge.io/pentobi-classic-small.png)

Pentobi is a computer opponent for the board game
[Blokus](https://en.wikipedia.org/wiki/Blokus). It has a strong Blokus engine
with different playing levels. The supported game variants are Classic, Duo,
Trigon, Junior, Nexos, GembloQ and Callisto.

See [INSTALL](INSTALL.md) for instructions how to build and install
the program from the sources. See [NEWS](NEWS.md) for release notes.
See [HACKING](HACKING.md) for an overview of the source code.

Contact
-------

The homepage of Pentobi is at https://pentobi.sourceforge.io/.

The maintainer of Pentobi is Markus Enzenberger. Please use the
[SourceForge bug tracker](https://sourceforge.net/p/pentobi/bugs/) and
[user forum](https://sourceforge.net/p/pentobi/discussion/) for bugs
and questions about released versions of Pentobi, and the
[development mailing list](https://sourceforge.net/projects/pentobi/lists/pentobi-devel)
and [GitHub tracker](https://github.com/enz/pentobi/issues) for
development-related issues.

License
-------

Copyright (C) 2011-2020 Markus Enzenberger.
See [AUTHORS](AUTHORS.md) for a full list of authors.

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. You should have received
[a copy](LICENSE.md) of the GNU General Public License along with this
program. If not, see <https://www.gnu.org/licenses/>.

### Trademark Disclaimer
The trademark Blokus and other trademarks referred to are property of
their respective trademark holders. The trademark holders are not
affiliated with the author of the program Pentobi.

==> pentobi_21.0.orig.tar.xz: pentobi-21.0/README.md <==
Pentobi Readme
==============

![Screenshot](https://pentobi.sourceforge.io/pentobi-classic-small.png)

Pentobi is a computer opponent for the board game
[Blokus](https://en.wikipedia.org/wiki/Blokus). It has a strong Blokus engine
with different playing levels. The supported game variants are Classic, Duo,
Trigon, Junior, Nexos, GembloQ and Callisto.

See [INSTALL](INSTALL.md) for instructions how to build and install
the program from the sources. See [NEWS](NEWS.md) for release notes.
See [CONTRIBUTING](CONTRIBUTING.md) for information on how to report bugs and
an overview of the source code.

Contact
-------

The homepage of Pentobi is at https://pentobi.sourceforge.io.
The maintainer of Pentobi is Markus Enzenberger.

License
-------

Copyright (C) 2011-2022 Markus Enzenberger.
See [AUTHORS](AUTHORS.md) for a full list of authors.

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. You should have received
[a copy](LICENSE.md) of the GNU General Public License along with this
program. If not, see <https://www.gnu.org/licenses/>.

### Trademark Disclaimer
The trademark Blokus and other trademarks referred to are property of
their respective trademark holders. The trademark holders are not
affiliated with the author of the program Pentobi.
